@@ -19,15 +19,14 @@ import six
 from warnings import warn
 from requests.compat import urljoin
 from praw.decorators import Memoize, SleepAfter, restrict_access
-from praw.errors import (ClientException, OAuthException,
+from praw.errors import (ClientException, InvalidSubreddit, OAuthException,
                          OAuthInsufficientScope, OAuthInvalidToken)
 
 
 def _get_section(subpath=''):
     """Return function to generate various non-subreddit listings."""
     def _section(self, sort='new', time='all', *args, **kwargs):
-        if not kwargs.get('params'):
-            kwargs['params'] = {}
+        kwargs.setdefault('params', {})
         kwargs['params'].setdefault('sort', sort)
         kwargs['params'].setdefault('t', time)
         url = urljoin(self._url, subpath)  # pylint: disable-msg=W0212
@@ -141,7 +140,11 @@ def _request(reddit_session, url, params=None, data=None, timeout=45,
         if response.status_code == 302:
             prev_url = url
             url = urljoin(url, response.headers['location'])
-            if 'random' not in prev_url:
+            if 'reddits/search?q=' in url:  # Handle non-existent subreddit
+                subreddit = url.rsplit('=', 1)[1]
+                raise InvalidSubreddit('`{0}` is not a valid subreddit'
+                                       .format(subreddit))
+            elif 'random' not in prev_url:
                 raise ClientException('Unexpected redirect from {0} to {1}'
                                       .format(prev_url, url))
         else:
