@@ -669,7 +669,7 @@ class LoggedInRedditor(Redditor):
     def get_cached_moderated_reddits(self):
         """Return a cached dictionary of the user's moderated reddits.
 
-        This list is used internally. Consider using the `my_moderation`
+        This list is used internally. Consider using the `get_my_moderation`
         function instead.
 
         """
@@ -755,7 +755,7 @@ class Submission(Editable, Hideable, Moderatable, Refreshable, Reportable,
             return c_info['data']['children']
         submission = s_info['data']['children'][0]
         submission.comments = c_info['data']['children']
-        submission._comment_sort = comment_sort
+        submission._comment_sort = comment_sort  # pylint: disable-msg=W0212
         return submission
 
     def __init__(self, reddit_session, json_dict):
@@ -957,8 +957,9 @@ class Subreddit(Messageable, Refreshable):
     get_controversial_from_month = _get_sorter('controversial', t='month')
     get_controversial_from_week = _get_sorter('controversial', t='week')
     get_controversial_from_year = _get_sorter('controversial', t='year')
-    get_new_by_date = _get_sorter('new', sort='new')
-    get_new_by_rising = _get_sorter('new', sort='rising')
+    get_new_by_date = _get_sorter('new', deprecated='get_new')
+    get_new_by_rising = _get_sorter('rising', deprecated='get_rising')
+    get_rising = _get_sorter('rising')
     get_top_from_all = _get_sorter('top', t='all')
     get_top_from_day = _get_sorter('top', t='day')
     get_top_from_hour = _get_sorter('top', t='hour')
