@@ -216,6 +216,15 @@ class BasicTest(unittest.TestCase, BasicHelper):
                           (isinstance(item, Comment) or
                            isinstance(item, MoreComments))])
 
+    def test_decode_entities(self):
+        text = self.r.get_submission(url=self.comment_url).selftext_html
+        self.assertTrue(text.startswith('&lt;'))
+        self.assertTrue(text.endswith('&gt;'))
+        self.r.config.decode_html_entities = True
+        text = self.r.get_submission(url=self.comment_url).selftext_html
+        self.assertTrue(text.startswith('<'))
+        self.assertTrue(text.endswith('>'))
+
     def test_equality(self):
         subreddit = self.r.get_subreddit(self.sr)
         same_subreddit = self.r.get_subreddit(self.sr)
@@ -356,16 +365,6 @@ class CacheTest(unittest.TestCase, AuthenticatedHelper):
         submission.refresh()
         self.assertNotEqual(submission.likes, same_submission.likes)
 
-    def test_users_share_cache(self):
-        subreddit = self.r.get_subreddit(self.sr)
-        title = 'Test User Sharing Of Cache: %s' % uuid.uuid4()
-        body = "BODY"
-        original_listing = list(subreddit.get_new(limit=5))
-        subreddit.submit(title, body)
-        self.r.login('PyAPITestUser2', '1111')
-        new_user_listing = list(subreddit.get_new(limit=5))
-        self.assertEqual(original_listing, new_user_listing)
-
 
 class EncodingTest(unittest.TestCase, AuthenticatedHelper):
     def setUp(self):
